diff mbox

Fix PR61070

Message ID alpine.LSU.2.11.1405061026330.18709@zhemvz.fhfr.qr
State New
Headers show

Commit Message

Richard Biener May 6, 2014, 8:27 a.m. UTC
Committed as obvious.

Richard.

2014-05-06  Richard Biener  <rguenther@suse.de>

	PR middle-end/61070
	* bitmap.c (debug_bitmap): Dump to stderr, not stdout.
	* tree-ssa-structalias.c (dump_solution_for_var): Likewise.
diff mbox

Patch

Index: gcc/bitmap.c
===================================================================
--- gcc/bitmap.c	(revision 210097)
+++ gcc/bitmap.c	(working copy)
@@ -2117,7 +2117,7 @@  debug_bitmap_file (FILE *file, const_bit
 DEBUG_FUNCTION void
 debug_bitmap (const_bitmap head)
 {
-  debug_bitmap_file (stdout, head);
+  debug_bitmap_file (stderr, head);
 }
 
 /* Function to print out the contents of a bitmap.  Unlike debug_bitmap_file,
Index: gcc/tree-ssa-structalias.c
===================================================================
--- gcc/tree-ssa-structalias.c	(revision 210097)
+++ gcc/tree-ssa-structalias.c	(working copy)
@@ -5834,12 +5834,12 @@  dump_solution_for_var (FILE *file, unsig
   fprintf (file, "\n");
 }
 
 /* Print the points-to solution for VAR to stdout.  */
 
 DEBUG_FUNCTION void
 debug_solution_for_var (unsigned int var)
 {
-  dump_solution_for_var (stdout, var);
+  dump_solution_for_var (stderr, var);
 }
 
 /* Create varinfo structures for all of the variables in the
@@ -5834,12 +5834,12 @@  dump_solution_for_var (FILE *file, unsig
 }
 
-/* Print the points-to solution for VAR to stdout.  */
+/* Print the points-to solution for VAR to stderr.  */
 
 DEBUG_FUNCTION void